Django-Chain-PyMySQL
--------------------

Easy to use PyMySQL in Django.

| 对 PyMySQL 进行封装，增加链式操作，方便快捷进行 CURD 操作
| > 注：基于 Chain-PyMySQL

说明文档
--------

https://github.com/Tiacx/django-chain-pymysql/
